Style guide — Invenio 3.1.2 documentation

# Style guide

This style guide can to a large degree be fully automated by your editor. See our Developer environment guide for help on how to setup your editor.

## Python

We follow PEP-8 and PEP-257 and sort imports via `isort`. Please plug corresponding linters such as `flake8` to your editor.

## Indention style and whitespace

Each repository contains a `.editorconfig` that defines the indention style, character set, trimming of trailing whitespace and final new lines.